@@ -13,7 +13,7 @@ async fn test_isolated_task_environment() -> Result<()> {
     // Spawn a task which prints a special environment variable.
     // This environment variable is injected into the daemon's environment.
     // It shouldn't show up in the task's environment, as the task should be isolated!
-    assert_success(add_task(shared, "echo $PUEUED_TEST_ENV_VARIABLE", true).await?);
+    assert_success(add_and_start_task(shared, "echo $PUEUED_TEST_ENV_VARIABLE").await?);
     wait_for_task_condition(shared, 0, |task| task.is_done()).await?;
 
     let log = get_task_log(shared, 0, None).await?;
